pub struct ReadSkillResourceTool { /* private fields */ }Expand description
Tool for reading resource files from activated skill directories.
Only allows reading from skills that have been activated via activate_skill.
Rejects path traversal attempts for security.
Implementations
Sourceimpl ReadSkillResourceTool
impl ReadSkillResourceTool
pub fn new(registry: Arc<RwLock<SkillRegistry>>) -> ReadSkillResourceTool
Sourcepub fn with_max_bytes(self, bytes: usize) -> ReadSkillResourceTool
pub fn with_max_bytes(self, bytes: usize) -> ReadSkillResourceTool
Set the maximum allowed resource file size in bytes.