parse_skill_md

Function parse_skill_md 

pub fn parse_skill_md(content: &str) -> Result<SkillDescriptor, ReactError>
Parse YAML frontmatter from a SKILL.md file.

Handles the common edge case of unquoted colons in values by retrying with the problematic value wrapped in quotes. Parse YAML frontmatter from a SKILL.md string into a SkillDescriptor.

Useful for manual/programmatic parsing of skill files.