pub struct InterruptConfig {
pub before: Vec<String>,
pub after: Vec<String>,
}Expand description
Interrupt configuration
Fields
before: Vec<String>Pause before entering these nodes
after: Vec<String>Pause after these nodes execute
Implementations
Sourceimpl InterruptConfig
impl InterruptConfig
pub fn new() -> InterruptConfig
Sourcepub fn should_interrupt_before(&self, node_name: &str) -> bool
pub fn should_interrupt_before(&self, node_name: &str) -> bool
Check if the node needs to pause before entering
Sourcepub fn should_interrupt_after(&self, node_name: &str) -> bool
pub fn should_interrupt_after(&self, node_name: &str) -> bool
Check if the node needs to pause after execution
Sourcepub fn has_interrupts(&self) -> bool
pub fn has_interrupts(&self) -> bool
Check if any interrupt is configured